@@ -524,10 +524,10 @@ augPred.gls <-
                        "without \"primary\" can only be used with fits of groupedData objects"))
         }
         primary <- getCovariate(data)
-        prName <- deparse(getCovariateFormula(data)[[2]])
+        prName <- c_deparse(getCovariateFormula(data)[[2]])
     } else{
         primary <- asOneSidedFormula(primary)[[2]]
-        prName <- deparse(primary)
+        prName <- c_deparse(primary)
         primary <- eval(primary, data)
     }
     newprimary <- seq(from = minimum, to = maximum, length.out = length.out)
@@ -612,7 +612,7 @@ comparePred.gls <-
                  length.out = length.out)
     if (!is.null(primary)) {
 	  ## need to do this before forcing the evaluations
-	  primary <- eval(asOneSidedFormula(primary)[[2]], 
+	  primary <- eval(asOneSidedFormula(primary)[[2]],
                          eval(object1$call$data))
         args[["minimum"]] <- minimum
         args[["maximum"]] <- maximum
@@ -758,7 +758,7 @@ intervals.gls <-
                 ## need to deleted components with fixed coefficients
                 aux <- glsSt[whichKeep]
                 class(aux) <- class(glsSt)
-                attr(aux, "settings") <- attr(lmeSt, "settings")
+                attr(aux, "settings") <- attr(glsSt, "settings")
                 attr(aux, "pmap") <- attr(glsSt, "pmap")[, whichKeep, drop = FALSE]
                 glsSt <- aux
             }
@@ -778,7 +778,8 @@ intervals.gls <-
             auxVal[["sigma"]] <- exp(aux[nP, ])
             attr(auxVal[["sigma"]], "label") <- "Residual standard error:"
             aux <- aux[-nP,, drop = FALSE]
-            rownames(aux) <- namP <- names(coef(glsSt, FALSE))
+            rownames(aux) <- ## namP <-
+                names(coef(glsSt, FALSE))
             for(i in 1:3) {
                 coef(glsSt) <- aux[,i]
                 aux[,i] <- coef(glsSt, unconstrained = FALSE)
@@ -1309,7 +1310,7 @@ glsControl <-
          singular.ok = singular.ok, qrTol = qrTol,
          returnObject = returnObject, apVar = apVar,
          minAbsParApVar = minAbsParApVar, .relStep = .relStep,
-         nlmStepMax = nlmStepMax, opt = match.arg(opt), 
+         nlmStepMax = nlmStepMax, opt = match.arg(opt),
 	 optimMethod = optimMethod, natural = natural)
 }
 
